@@ -1,4 +1,4 @@
-/* $Id: DBIXS.h,v 11.10 2002/11/26 00:20:33 timbo Exp $
+/* $Id: DBIXS.h,v 11.12 2003/02/26 17:56:01 timbo Exp $
  *
  * Copyright (c) 1994-2002  Tim Bunce  Ireland
  *
@@ -234,6 +234,7 @@ typedef struct {		/* -- FIELD DESCRIPTOR --		*/
 #define DBIcf_Profile     0x010000	/* profile activity on this handle      */
 #define DBIcf_TaintIn     0x020000	/* check inputs for taintedness */
 #define DBIcf_TaintOut    0x040000	/* taint outgoing data */
+/* new flags may require clone() to be updated */
 
 #define DBIcf_INHERITMASK		/* what NOT to pass on to children */	\
   (U32)( DBIcf_COMSET | DBIcf_IMPSET | DBIcf_ACTIVE | DBIcf_IADESTROY		\
@@ -442,10 +443,10 @@ static dbistate_t **get_dbistate() {
 /* attribs value. One day we may add some extra magic in here.		*/
 #define DBD_ATTRIBS_CHECK(func, h, attribs)	\
     if ((attribs) && SvOK(attribs)) {		\
-	STRLEN lna=0;				\
+	STRLEN lna1=0, lna2=0;			\
 	if (!SvROK(attribs) || SvTYPE(SvRV(attribs))!=SVt_PVHV)		\
 	    croak("%s->%s(...): attribute parameter '%s' is not a hash ref",	\
-		    SvPV(h,lna), func, SvPV(attribs,lna));		\
+		    SvPV(h,lna1), func, SvPV(attribs,lna2));		\
     } else (attribs) = Nullsv
 
 #define DBD_ATTRIB_GET_SVP(attribs, key,klen)			\
